# Generated by roxygen2: do not edit by hand

export(CFI)
export(ConditionalARFSampler)
export(ConditionalCtreeSampler)
export(ConditionalGaussianSampler)
export(ConditionalKNNSampler)
export(ConditionalSAGE)
export(ConditionalSampler)
export(FeatureImportanceMethod)
export(FeatureSampler)
export(KnockoffGaussianSampler)
export(KnockoffSampler)
export(LOCO)
export(MarginalPermutationSampler)
export(MarginalReferenceSampler)
export(MarginalSAGE)
export(MarginalSampler)
export(PFI)
export(PerturbationImportance)
export(RFI)
export(SAGE)
export(WVIM)
export(check_groups)
export(rsmp_all_test)
export(sim_dgp_confounded)
export(sim_dgp_correlated)
export(sim_dgp_ewald)
export(sim_dgp_independent)
export(sim_dgp_interactions)
export(sim_dgp_mediated)
export(wvim_design_matrix)
export(xplain_opt)
if (getRversion() < "4.4.0") export(`%||%`)
import(data.table)
importFrom(R6,R6Class)
importFrom(checkmate,"%??%")
importFrom(cli,cli)
importFrom(mlr3,PredictionClassif)
importFrom(mlr3,PredictionRegr)
importFrom(mlr3,as_resample_result)
importFrom(mlr3,assert_task)
importFrom(mlr3,resample)
importFrom(mlr3,rsmp)
importFrom(mlr3fselect,fs)
importFrom(mlr3fselect,fselect)
importFrom(mvtnorm,rmvnorm)
importFrom(paradox,ps)
importFrom(stats,binom.test)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(tools,toRd)
importFrom(utils,bibentry)
importFrom(utils,packageVersion)
importFrom(utils,person)
