#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import data.table
#' @importFrom checkmate %??%
#' @importFrom cli cli
#' @importFrom mlr3 resample PredictionClassif PredictionRegr
#' @importFrom mvtnorm rmvnorm
#' @importFrom paradox ps
#' @importFrom R6 R6Class
#' @importFrom stats var sd quantile qt binom.test runif rnorm
#' @importFrom utils packageVersion
## usethis namespace: end
NULL
