# This file is part of the standard setup for testthat.
# It is recommended that you do not modify it.
#
# Where should you do additional test configuration?
# Learn more about the roles of various files in:
# * https://r-pkgs.org/testing-design.html#sec-tests-files-overview
# * https://testthat.r-lib.org/articles/special-files.html

# Cap threads before any BLAS/OpenMP init: CRAN's Debian machine links a multithreaded (OpenMP) BLAS whose
# spin-pool inflates the CPU/elapsed ratio. Must be set here, before library() and any matrix op, to take effect.
Sys.setenv("OMP_THREAD_LIMIT" = 2)

library(testthat)
library(xplainfi)

test_check("xplainfi")
